==> haskell-yesod-static-1.6.1.0-882-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-9JlbX6ZDB4DLTMDXlyza2z
key:                  yesod-static-1.6.1.0-9JlbX6ZDB4DLTMDXlyza2z
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  c9b04ace3ec17ea247d90e781563cfd4
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-9JlbX6ZDB4DLTMDXlyza2z
depends:
    async-2.2.5-JsOMVyOozRP6jACwcJZjUc
    attoparsec-0.14.4-BuoYNqKkZ0cK5gzfHXNsJW base-4.17.2.1
    base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    blaze-builder-0.4.3-CCGWpBjxAylCkXXKn5PO27 bytestring-0.11.5.3
    conduit-1.3.6.1-2lml8TYLrSoCJWeVqTIcf8 containers-0.6.7
    cryptonite-0.30-7RGQk4m0UZG21KYNtSxwaa
    cryptonite-conduit-0.2.2-C6pwE2NJWKJGZ10Wfmhs4a
    css-text-0.1.3.0-C4EbLqpZrNzKLlwSjCmzCw
    data-default-0.7.1.2-8zpNuXeugnsCXhsU9L7wsy directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashable-1.4.4.0-C1fFIG7AZLC7j0jzLm97Uw
    hjsmin-0.2.1-Brn8ARAXLu9JLB8kY11IbK
    http-types-0.12.4-22ca4VB3NcX8GYX2Ium30U
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq process-1.6.18.0
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2
    unix-compat-0.7.4-8PAyJFIzbO7LjuiJWjVyWo
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP
    wai-3.2.4-EhNMiHqwqcPHb2wBYuWApz
    wai-app-static-3.1.9-CegJlCEkpov4OB1Jh8hhTW
    yesod-core-1.6.27.1-6rT6Bxwfg7f1GkDs7zSM2U

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.1.0-883-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-5nV5yiHH8Lx8YmG972NG0H
key:                  yesod-static-1.6.1.0-5nV5yiHH8Lx8YmG972NG0H
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  4c13c67aac8cfaae59f01abee4ff8e7f
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-5nV5yiHH8Lx8YmG972NG0H
depends:
    async-2.2.5-IoLsQL5aW4y4qbn8NJyPCy
    attoparsec-0.14.4-fEKSJrOU814GdIIzzkkyx base-4.17.2.1
    base64-bytestring-1.2.1.0-ALlNDgCJ5uI9xkCg0LJBoH
    blaze-builder-0.4.3-BgDmm9LLPQj70kDL41wf1H bytestring-0.11.5.3
    conduit-1.3.6.1-GExfIrooWL7LwgSGxPA8ji containers-0.6.7
    cryptonite-0.30-CuyVAaLmJNF5moPTPURptl
    cryptonite-conduit-0.2.2-8gfIJhm6MBoFqLrmPiJhBa
    css-text-0.1.3.0-8HZ7wBigw077TBROZ7zr0v
    data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashable-1.4.4.0-1zcla4qwUGf6ADT5z5m7Nb
    hjsmin-0.2.1-22Yjdggyufa5im5YyY9Shu
    http-types-0.12.4-IhtLMXP6VlH4EvGJYn8uz7
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq process-1.6.18.0
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2
    unix-compat-0.7.4-3SBsXwUhhAM1AlokChSoJS
    unordered-containers-0.2.20-5ChD9TF8iAH5uLARI0QLMz
    wai-3.2.4-EOBJdwgqwP2ZRndhZ2MHb
    wai-app-static-3.1.9-Q197AdCqoXVZiujIT5l5
    yesod-core-1.6.27.1-FGipcORE225Hil8iLY6vT

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
